package mnotty
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
Notty ✕ Miou
A simple library which implements the scheduler-logic needed by notty to play with your terminal. A "game-of-life" example exists and you can execute it with (you can stop the application with Esc or Ctrl^C):
$ git clone https://github.com/robur-coop/notty-miou
$ cd notty-miou
$ opam pin add -y .
$ dune exec bin/life.exe